==> haskell-split-0.2.3.2-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-split.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: split
version: 0.2.3.2
id: split-0.2.3.2-CJl40zTyCIV16Pr60nb7CT
key: split-0.2.3.2-CJl40zTyCIV16Pr60nb7CT
license: BSD3
copyright: (c) Brent Yorgey, Louis Wasserman 2008-2012
maintainer: byorgey@gmail.com
stability: stable
synopsis: Combinator library for splitting lists.
description:
    A collection of various methods for splitting
    lists into parts, akin to the \"split\" function
    found in several mainstream languages. Here is
    its tale:
    .
    Once upon a time the standard "Data.List" module
    held no function for splitting a list into parts
    according to a delimiter.  Many a brave
    lambda-knight strove to add such a function, but
    their striving was in vain, for Lo, the Supreme
    Council fell to bickering amongst themselves what
    was to be the essential nature of the One True
    Function which could cleave a list in twain (or
    thrain, or any required number of parts).
    .
    And thus came to pass the split package,
    comprising divers functions for splitting a list
    asunder, each according to its nature.  And the
    Supreme Council had no longer any grounds for
    argument, for the favored method of each was
    contained therein.
    .
    To get started, see the "Data.List.Split" module.
category: List
author: Brent Yorgey
exposed: True
exposed-modules:
    Data.List.Split Data.List.Split.Internals
abi: 4c9359eda383281d1a12f9e53c83d812
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/split-0.2.3.2
library-dirs: /usr/lib/ghc-8.0.2/site-local/split-0.2.3.2
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/split-0.2.3.2
hs-libraries: HSsplit-0.2.3.2-CJl40zTyCIV16Pr60nb7CT
depends:
    base-4.9.1.0
haddock-interfaces: /usr/share/doc/haskell-split/html/split.haddock
haddock-html: /usr/share/doc/haskell-split/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-split-0.2.3.2-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-split.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: split
version: 0.2.3.2
id: split-0.2.3.2-89BHvn20PlL73pGr1SBIHj
key: split-0.2.3.2-89BHvn20PlL73pGr1SBIHj
license: BSD3
copyright: (c) Brent Yorgey, Louis Wasserman 2008-2012
maintainer: byorgey@gmail.com
stability: stable
synopsis: Combinator library for splitting lists.
description:
    A collection of various methods for splitting
    lists into parts, akin to the \"split\" function
    found in several mainstream languages. Here is
    its tale:
    .
    Once upon a time the standard "Data.List" module
    held no function for splitting a list into parts
    according to a delimiter.  Many a brave
    lambda-knight strove to add such a function, but
    their striving was in vain, for Lo, the Supreme
    Council fell to bickering amongst themselves what
    was to be the essential nature of the One True
    Function which could cleave a list in twain (or
    thrain, or any required number of parts).
    .
    And thus came to pass the split package,
    comprising divers functions for splitting a list
    asunder, each according to its nature.  And the
    Supreme Council had no longer any grounds for
    argument, for the favored method of each was
    contained therein.
    .
    To get started, see the "Data.List.Split" module.
category: List
author: Brent Yorgey
exposed: True
indefinite: False
exposed-modules:
    Data.List.Split Data.List.Split.Internals
abi: c51f43c3e91d41531ae5282d108271a0
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/split-0.2.3.2
library-dirs: /usr/lib/ghc-8.2.1/site-local/split-0.2.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/split-0.2.3.2
hs-libraries: HSsplit-0.2.3.2-89BHvn20PlL73pGr1SBIHj
depends:
    base-4.10.0.0
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
haddock-interfaces: /usr/share/doc/haskell-split/html/split.haddock
haddock-html: /usr/share/doc/haskell-split/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
